@@ -1,21 +1,8 @@
 /*
-   This file is part of the KDE games lskat program
-   Copyright (c) 2006 Martin Heni <kde@heni-online.de>
+    This file is part of the KDE games lskat program
+    SPDX-FileCopyrightText: 2006 Martin Heni <kde@heni-online.de>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "mainwindow.h"
@@ -29,7 +16,8 @@
 #include <QStatusBar>
 #include <QStandardPaths>
 
-// Include files for KDE
+// KF includes
+#include <kwidgetsaddons_version.h>
 #include <KActionCollection>
 #include <KConfigGroup>
 #include <KMessageBox>
@@ -90,7 +78,7 @@ Mainwindow::Mainwindow(QWidget *parent)
     if (themeList.isEmpty())
     {
         KMessageBox::error(this, i18n("Installation error: No theme list found."));
-        QTimer::singleShot(0, this, SLOT(close()));
+        QTimer::singleShot(0, this, &QWidget::close);
         return;
     }
 
@@ -137,7 +125,7 @@ Mainwindow::Mainwindow(QWidget *parent)
     if (mTheme->checkTheme() != 0)
     {
         KMessageBox::error(this, i18n("Installation error: Theme file error."));
-        QTimer::singleShot(0, this, SLOT(close()));
+        QTimer::singleShot(0, this, &QWidget::close);
         return;
     }
 
@@ -166,7 +154,7 @@ Mainwindow::Mainwindow(QWidget *parent)
     {
         // Start intro
         mDisplay->start();
-        QTimer::singleShot(12500, this, SLOT(menuNewLSkatGame()));
+        QTimer::singleShot(12500, this, &Mainwindow::menuNewLSkatGame);
     }
     else
     {
@@ -275,20 +263,20 @@ AbstractInput *Mainwindow::createInput(
     if (inputType == TypeMouseInput)
     {
         MouseInput *mouseInput = new MouseInput(this);
-        connect((QObject *)mView, SIGNAL(signalLeftMousePress(QPoint)),
-                mouseInput, SLOT(mousePress(QPoint)));
-        connect(mouseInput, SIGNAL(signalConvertMousePress(QPoint,int&,int&)),
-                display, SLOT(convertMousePress(QPoint,int&,int&)));
-        connect(mouseInput, SIGNAL(signalPlayerInput(int,int,int)),
-                engine, SLOT(playerInput(int,int,int)));
+        connect(mView, &GameView::signalLeftMousePress,
+                mouseInput, &MouseInput::mousePress);
+        connect(mouseInput, &MouseInput::signalConvertMousePress,
+                display, &AbstractDisplay::convertMousePress);
+        connect(mouseInput, &MouseInput::signalPlayerInput,
+                engine, &AbstractEngine::playerInput);
         input = mouseInput;
         if (global_debug > 0) qCDebug(LSKAT_LOG) << "Create MOUSE INPUT";
     }
     else if (inputType == TypeAiInput)
     {
         AiInput *aiInput = new AiInput((EngineTwo *)engine, this);
-        connect(aiInput, SIGNAL(signalPlayerInput(int,int,int)),
-                engine, SLOT(playerInput(int,int,int)));
+        connect(aiInput, &AiInput::signalPlayerInput,
+                engine, &AbstractEngine::playerInput);
         input = aiInput;
         if (global_debug > 0) qCDebug(LSKAT_LOG) << "Create AI INPUT";
     }
@@ -348,7 +336,7 @@ void Mainwindow::gameOver(int /*winner*/)
     // Automatically restart game in demo mode
     if (global_demo_mode)
     {
-        QTimer::singleShot(10000, this, SLOT(menuNewLSkatGame()));
+        QTimer::singleShot(10000, this, &Mainwindow::menuNewLSkatGame);
     }
 }
 
@@ -366,27 +354,31 @@ void Mainwindow::initGUI()
     QAction *action;
 
     // Start a new game
-    action = KStandardGameAction::gameNew(this, SLOT(menuNewLSkatGame()), actionCollection());
+    action = KStandardGameAction::gameNew(this, &Mainwindow::menuNewLSkatGame, actionCollection());
     if (global_demo_mode) action->setEnabled(false);
 
     // Clear all time statistics
-    action = KStandardGameAction::clearStatistics(this, SLOT(menuClearStatistics()), actionCollection());
+    action = KStandardGameAction::clearStatistics(this, &Mainwindow::menuClearStatistics, actionCollection());
     action->setWhatsThis(i18n("Clears the all time statistics which is kept in all sessions."));
     if (global_demo_mode) action->setEnabled(false);
 
     // End a game
-    action = KStandardGameAction::end(this, SLOT(menuEndGame()), actionCollection());
+    action = KStandardGameAction::end(this, &Mainwindow::menuEndGame, actionCollection());
     action->setWhatsThis(i18n("Ends a currently played game. No winner will be declared."));
     action->setEnabled(false);
 
     // Quit the program
-    action = KStandardGameAction::quit(this, SLOT(close()), actionCollection());
+    action = KStandardGameAction::quit(this, &QWidget::close, actionCollection());
     action->setWhatsThis(i18n("Quits the program."));
 
     // Determine start player
     KSelectAction *startPlayerAct = new KSelectAction(i18n("Starting Player"), this);
     actionCollection()->addAction(QStringLiteral("startplayer"), startPlayerAct);
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 78, 0)
+    connect(startPlayerAct, &KSelectAction::indexTriggered, this, &Mainwindow::menuStartplayer);
+#else
     connect(startPlayerAct, static_cast<void (KSelectAction::*)(int)>(&KSelectAction::triggered), this, &Mainwindow::menuStartplayer);
+#endif
     startPlayerAct->setToolTip(i18n("Changing starting player..."));
     startPlayerAct->setWhatsThis(i18n("Chooses which player begins the next game."));
     QStringList list;
@@ -399,7 +391,11 @@ void Mainwindow::initGUI()
     // Determine who plays player 1
     KSelectAction *player1Act = new KSelectAction(i18n("Player &1 Played By"), this);
     actionCollection()->addAction(QStringLiteral("player1"), player1Act);
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 78, 0)
+    connect(player1Act, &KSelectAction::indexTriggered, this, &Mainwindow::menuPlayer1By);
+#else
     connect(player1Act, static_cast<void (KSelectAction::*)(int)>(&KSelectAction::triggered), this, &Mainwindow::menuPlayer1By);
+#endif
     player1Act->setToolTip(i18n("Changing who plays player 1..."));
     player1Act->setWhatsThis(i18n("Changing who plays player 1."));
     list.clear();
@@ -411,7 +407,11 @@ void Mainwindow::initGUI()
     // Determine who plays player 2
     KSelectAction *player2Act = new KSelectAction(i18n("Player &2 Played By"), this);
     actionCollection()->addAction(QStringLiteral("player2"), player2Act);
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 78, 0)
+    connect(player2Act, &KSelectAction::indexTriggered, this, &Mainwindow::menuPlayer2By);
+#else
     connect(player2Act, static_cast<void (KSelectAction::*)(int)>(&KSelectAction::triggered), this, &Mainwindow::menuPlayer2By);
+#endif
     player2Act->setToolTip(i18n("Changing who plays player 2..."));
     player2Act->setWhatsThis(i18n("Changing who plays player 2."));
     player2Act->setItems(list);
@@ -424,7 +424,11 @@ void Mainwindow::initGUI()
     KSelectAction *themeAct = new KSelectAction(i18n("&Theme"), this);
     actionCollection()->addAction(QStringLiteral("theme"), themeAct);
     themeAct->setItems(themes);
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 78, 0)
+    connect(themeAct, &KSelectAction::indexTriggered, this, &Mainwindow::changeTheme);
+#else
     connect(themeAct, static_cast<void (KSelectAction::*)(int)>(&KSelectAction::triggered), this, &Mainwindow::changeTheme);
+#endif
     if (global_debug > 0) qCDebug(LSKAT_LOG) << "Setting current theme item to " << mThemeIndexNo;
     themeAct->setCurrentItem(mThemeIndexNo);
     themeAct->setToolTip(i18n("Changing theme..."));
@@ -563,14 +567,15 @@ void Mainwindow::menuNewLSkatGame()
         delete mDisplay;
         delete mEngine;
 
-        mDisplay = new DisplayTwo(mDeck, mCanvas, mTheme, ADVANCE_PERIOD, mView);
+        auto *display = new DisplayTwo(mDeck, mCanvas, mTheme, ADVANCE_PERIOD, mView);
+        mDisplay = display;
         mEngine = new EngineTwo(this, mDeck, (DisplayTwo *)mDisplay);
         connect(mEngine, &AbstractEngine::signalGameOver, this, &Mainwindow::gameOver);
         connect(mEngine, &AbstractEngine::signalNextPlayer, this, &Mainwindow::nextPlayer);
 
         // Connect player score widget updates
-        connect(p1, SIGNAL(signalUpdate(Player*)), mDisplay, SLOT(updatePlayer(Player*)));
-        connect(p2, SIGNAL(signalUpdate(Player*)), mDisplay, SLOT(updatePlayer(Player*)));
+        connect(p1, &Player::signalUpdate, display, &DisplayTwo::updatePlayer);
+        connect(p2, &Player::signalUpdate, display, &DisplayTwo::updatePlayer);
 
         mEngine->addPlayer(0, p1);
         mEngine->addPlayer(1, p2);
